@@ -541,6 +541,9 @@ class SwanGraph(Graph):
 				locs[key] = vertex_id
 				vertex_id += 1
 
+		# create inverse loc dict to sort paths by
+		locs_inv = {v: k for k, v in locs.items()}
+
 		# add locs-indexed path to transcripts, and populate edges
 		edges = {}
 		for _,t in transcripts.items():
@@ -580,6 +583,10 @@ class SwanGraph(Graph):
 					if key not in edges:
 						edges[key] = {'edge_id': edge_id, 'edge_type': 'intron'}
 
+			# sort the path based on chromosomal coordinates and strand
+			# in case there's some weird ordering in the gtf 
+			t['path'] = reorder_locs(t['path'], strand, locs_inv)
+
 		# turn transcripts, edges, and locs into dataframes
 		locs = [{'chrom': key[0],
 				 'coord': key[1],
